@@ -304,6 +304,8 @@ public:
   virtual void aggregateFlowValuesFromLeafToRoot();
 
   // Init terms that is constant for the whole network
+  virtual void initTree() = 0;
+
   virtual void initNetwork() = 0;
 
   virtual void initSuperNetwork() = 0;
@@ -432,7 +434,7 @@ public:
    */
   std::string writeNewickTree(std::string filename = "", bool states = false);
 
-  std::string writeJsonTree(std::string filename = "", bool states = false);
+  std::string writeJsonTree(std::string filename = "", bool states = false, bool writeLinks = false);
 
   std::string writeCsvTree(std::string filename = "", bool states = false);
 
@@ -492,7 +494,7 @@ protected:
    * Write JSON tree to output stream
    * @param states, write state-level tree, else aggregate physical nodes within modules
    */
-  void writeJsonTree(std::ostream& outStream, bool states = false);
+  void writeJsonTree(std::ostream& outStream, bool states = false, bool writeLinks = false);
 
   /**
    * Write CSV tree to output stream
@@ -500,6 +502,8 @@ protected:
    */
   void writeCsvTree(std::ostream& outStream, bool states = false);
 
+  std::map<std::string, std::map<std::pair<unsigned int, unsigned int>, double>> aggregateModuleLinks(bool states = false);
+
   InfoNode m_root;
   std::vector<InfoNode*> m_leafNodes;
   std::vector<InfoNode*> m_moduleNodes;
