@@ -26,72 +26,37 @@
 
 
 #include "FileURI.h"
-#include <stdexcept>
 #include "../io/convert.h"
+#include <stdexcept>
+#include <utility>
+
+using std::string;
 
 namespace infomap {
 
-FileURI::FileURI()
-    : m_filename(""),
-      m_requireExtension(false),
-      m_directory(""),
-      m_name(""),
-      m_extension("")
+FileURI::FileURI(string filename, bool requireExtension)
+    : m_filename(std::move(filename)), m_requireExtension(requireExtension)
 {
-}
+  auto getErrorMessage = [](const auto& filename, auto requireExt) {
+    string s = io::Str() << "Filename '" << filename << "' must match the pattern \"[dir/]name" << (requireExt ? ".extension\"" : "[.extension]\"");
+    return s;
+  };
 
-FileURI::FileURI(const char* filename, bool requireExtension)
-    : m_filename(filename),
-      m_requireExtension(requireExtension)
-{
-  analyzeFilename();
-}
-
-FileURI::FileURI(const string& filename, bool requireExtension)
-    : m_filename(filename),
-      m_requireExtension(requireExtension)
-{
-  analyzeFilename();
-}
-
-FileURI::FileURI(const FileURI& other)
-    : m_filename(other.m_filename),
-      m_requireExtension(other.m_requireExtension),
-      m_directory(other.m_directory),
-      m_name(other.m_name),
-      m_extension(other.m_extension)
-{
-}
-
-
-FileURI& FileURI::operator=(const FileURI& other)
-{
-  m_filename = other.m_filename;
-  m_requireExtension = other.m_requireExtension;
-  m_directory = other.m_directory;
-  m_name = other.m_name;
-  m_extension = other.m_extension;
-  return *this;
-}
-
-
-void FileURI::analyzeFilename()
-{
-  string name = m_filename;
-  size_t pos = m_filename.find_last_of("/");
+  auto name = m_filename;
+  auto pos = m_filename.find_last_of('/');
   if (pos != string::npos) {
     if (pos == m_filename.length()) // File could not end with slash
-      throw std::invalid_argument(getErrorMessage());
+      throw std::invalid_argument(getErrorMessage(m_filename, m_requireExtension));
     m_directory = m_filename.substr(0, pos + 1); // Include the last slash in the directory
     name = m_filename.substr(pos + 1); // No slash in the name
   } else {
     m_directory = "";
   }
 
-  pos = name.find_last_of(".");
+  pos = name.find_last_of('.');
   if (pos == string::npos || pos == 0 || pos == name.length() - 1) {
     if (pos != string::npos || m_requireExtension)
-      throw std::invalid_argument(getErrorMessage());
+      throw std::invalid_argument(getErrorMessage(m_filename, m_requireExtension));
     m_name = name;
     m_extension = "";
   } else {
@@ -100,9 +65,4 @@ void FileURI::analyzeFilename()
   }
 }
 
-string FileURI::getErrorMessage()
-{
-  return io::Str() << "Filename '" << m_filename << "' must match the pattern \"[dir/]name" << (m_requireExtension ? ".extension\"" : "[.extension]\"");
-}
-
 } // namespace infomap
